small performance improvemnt when using synchronize: polling reduced from 100ms to 50ms
Build Debian Packages / build (trixie, debian13) (push) Successful in 16m24s
Build Debian Packages / build (bookworm, debian12) (push) Successful in 16m38s

This commit is contained in:
markusro committed 2026-07-13 22:21:49 +02:00
1 parent 696cdfb556
commit fa064c1727
2 files changed
+2 -2

No files matched your search

+1 -1
View File
@@ -4032,7 +4032,7 @@ class ScriptInterface:
(self.back_driver.core_pid is None or self.back_driver.core_pid <= 0)):
while gtk.events_pending():
gtk.main_iteration_do(False)
self.back_driver.quit_flag.wait( 0.1 )
self.back_driver.quit_flag.wait( 0.05 )
if self.exp_handling:
self.exp_handling.start( )
if self.res_handling: